@@ -5,7 +5,7 @@
 modname = "dataprocessing"
 distname = "cubicweb-dataprocessing"
 
-numversion = (0, 6, 0)
+numversion = (0, 8, 0)
 version = ".".join(str(num) for num in numversion)
 
 license = "LGPL"
@@ -15,7 +15,7 @@ description = "Data validation and transformation process"
 web = "http://www.cubicweb.org/project/%s" % distname
 
 __depends__ = {
-    "cubicweb": ">= 3.24.0., < 3.37.0",
+    "cubicweb": ">= 3.38.0, < 3.39.0",
     "cubicweb-file": None,
 }
 __recommends__ = {}
